==> tim_ui_kit_push_plugin-0.1.12-special.tar.gz: lib/tim_ui_kit_push_plugin.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:tim_ui_kit_push_plugin/model/appInfo.dart';
import 'package:tim_ui_kit_push_plugin/channel/apple_apns_impl.dart';
import 'package:tim_ui_kit_push_plugin/utils/utils.dart';
import 'dart:io' show Platform;

import 'channel/flutter_push_base_impl.dart';
import 'channel/google_fcm_impl.dart';
import 'channel/huawei_apns_impl.dart';
export 'model/appInfo.dart';

typedef PushClickAction = void Function(Map<String, dynamic> msg);

class TimUiKitPushPlugin {
  static TimUiKitPushPlugin? _instance;
  TimUiKitPushPlugin._internal({bool? isUseGoogleFCM}) {
    _initPlugin(isUseGoogleFCM);
  }

  /// Initilialize this plug-in. `isUseGoogleFCM` means if Google FCM needed, require Google Service on device, depends on your main customers and users
  factory TimUiKitPushPlugin({bool? isUseGoogleFCM}) {
    _instance ??= TimUiKitPushPlugin._internal(isUseGoogleFCM: isUseGoogleFCM);
    return _instance!;
  }

  static const MethodChannel _channel = MethodChannel('tim_ui_kit_push_plugin');

  /// If Google FCM needed, require Google Service on device, depends on your main customers and users
  late final bool isUseGoogleFCM;

  /// [Developers should not use this field directly] Flutter push implement
  late final FlutterPushBase flutterPush;

  /// [Developers should not use this field directly] Bind the click callback
  PushClickAction? onClickNotification;

  /// [Developers should not use this field directly] Determine whether to execute the push logic in the Dart layer
  bool isUseFlutterPlugin = false;

  /// [Developers should not use this field directly] Constructor, initialize the plug-in
  _initPlugin(isUseGoogleFCMBool) {
    _channel.setMethodCallHandler(_handleMethod);
    isUseGoogleFCM = isUseGoogleFCMBool;
    if(isUseGoogleFCM){
      flutterPush = GoogleFCMImpl();
      if(flutterPush.isSupport()){
        print("TUIKitPush | Dart Plugin | USE_GOOGLE_FCM");
        isUseFlutterPlugin = true;
      }
    }
    if(Platform.isIOS){
      print("TUIKitPush | Dart Plugin | USE_iOS");
      isUseFlutterPlugin = true;
      flutterPush = AppleAPNSImpl();
    }
  }

  /// get version
  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }


  Future<dynamic> _handleMethod(MethodCall call) async {
    switch (call.method) {
      case "TIMPushClickAction":
        print("TUIKitPush | Dart Plugin | on_handleMethod | TIMPushClickAction");
        return onClickNotification!(call.arguments.cast<String, dynamic>());
      default:
        throw UnsupportedError("Unrecongnized Event");
    }
  }

  /// Initialize the push capobility for each channel
  void init(
      {required PushClickAction pushClickAction,  PushAppInfo? appInfo}) async{

    if(Platform.isAndroid && await _channel.invokeMethod("isEmuiRom")){
      // 因华为需要使用native异步校验，放到这边进行
      print("TUIKitPush | Dart Plugin | USE HUAWEI");
      isUseFlutterPlugin = true;
      flutterPush = HuaweiImpl();
    }

    print("TUIKitPush | DART | INIT, isUseFlutterPlugin: $isUseFlutterPlugin");
    onClickNotification = pushClickAction;

    if(isUseFlutterPlugin){
      flutterPush.init(pushClickAction);
      return;
    }

    if(Platform.isAndroid && appInfo != null){
      await Utils.setAppInfoForChannel(_channel, appInfo);
    }

    _channel.invokeMethod("initPush");
  }

  /// Require the notification permission
  Future<void> requireNotificationPermission() async {
    if(isUseFlutterPlugin){
      flutterPush.requirePermission();
    }
    await _channel.invokeMethod("getNotificationPermission");
    return;
  }

  /// Get the Device Push token
  Future<String> getDevicePushToken() async {
    String token = "";
    try {
      if(isUseFlutterPlugin){
        print("TUIKitPush | Dart | getTokenByFlutter");
        token = await flutterPush.getToken() ?? flutterPush.token;
        print("TUIKitPush | Dart | getTokenByFlutter | DeviceToken: $token");
      } else{
        print("TUIKitPush | Dart | getTokenByNative");
        token = await _channel.invokeMethod("getPushToken");
        print("TUIKitPush | Dart | getTokenByNative | DeviceToken: $token");
      }
    } catch (err) {
      print("getDevicePushToken err $err");
    }
    return token;
  }

  /// Get the brand of the manufacturer in lowercase letter format, only works for Android device
  static Future<String?> getOtherPushType() async {
    return await _channel.invokeMethod("getDeviceManufacturer");
  }

  /// Find the buz_id for current device from `PushAppInfo`
  static Future<int?> getBuzId(PushAppInfo appInfo) async {
    if(Platform.isIOS){
      return appInfo.apple_buz_id;
    }
    String device = await getOtherPushType() ?? "";
    print("TUIKitPush | Dart | getOtherPushType | device: $device");
    switch (device){
      case 'oppo':
      case 'oneplus':
      case 'realme':
        if(appInfo.oppo_buz_id != null){
          return appInfo.oppo_buz_id;
        }
        break;
      case 'xiaomi':
      case 'mi':
      case 'blackshark':
        if(appInfo.mi_buz_id != null){
          return appInfo.mi_buz_id;
        }
        break;
      case 'huawei':
      case 'honor':
        if(appInfo.hw_buz_id != null){
          return appInfo.hw_buz_id;
        }
        break;
      case 'meizu':
        if(appInfo.mz_buz_id != null){
          return appInfo.mz_buz_id;
        }
        break;
      case 'vivo':
      case 'iqoo':
        if(appInfo.vivo_buz_id != null){
          return appInfo.vivo_buz_id;
        }
        break;
      default:
        if(appInfo.google_buz_id != null){
          return appInfo.google_buz_id;
        }
        break;
    }

    if(await _channel.invokeMethod("isOppoRom") && appInfo.oppo_buz_id != null){
      return appInfo.oppo_buz_id;
    }
    if(await _channel.invokeMethod("isMiuiRom") && appInfo.mi_buz_id != null){
      return appInfo.mi_buz_id;
    }
    if(await _channel.invokeMethod("isEmuiRom") && appInfo.hw_buz_id != null){
      return appInfo.hw_buz_id;
    }
    if(await _channel.invokeMethod("isMeizuRom") && appInfo.mz_buz_id != null){
      return appInfo.mz_buz_id;
    }
    if(await _channel.invokeMethod("isVivoRom") && appInfo.vivo_buz_id != null){
      return appInfo.vivo_buz_id;
    }
    if(appInfo.google_buz_id != null){
      return appInfo.google_buz_id;
    }

    return 0;
  }


  /// Create notification channel, only works for Android device
  void createNotificationChannel(
      {required String channelId,
      required String channelName,
      required String channelDescription}) async{

    if (Platform.isAndroid) {
      _channel.invokeMethod("createNotificationChannel", {
        "channelId": channelId,
        "channelName": channelName,
        "channelDescription": channelDescription
      });
    }
  }
}

==> tim_ui_kit_push_plugin-0.1.16-special.tar.gz: lib/tim_ui_kit_push_plugin.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:tim_ui_kit_push_plugin/model/appInfo.dart';
import 'package:tim_ui_kit_push_plugin/channel/apple_apns_impl.dart';
import 'package:tim_ui_kit_push_plugin/utils/utils.dart';
import 'dart:io' show Platform;

import 'channel/flutter_push_base_impl.dart';
import 'channel/google_fcm_impl.dart';
import 'channel/huawei_apns_impl.dart';
export 'model/appInfo.dart';

typedef PushClickAction = void Function(Map<String, dynamic> msg);

class TimUiKitPushPlugin {
  static TimUiKitPushPlugin? _instance;
  TimUiKitPushPlugin._internal({bool? isUseGoogleFCM}) {
    _initPlugin(isUseGoogleFCM);
  }

  /// Initilialize this plug-in. `isUseGoogleFCM` means if Google FCM needed, require Google Service on device, depends on your main customers and users
  factory TimUiKitPushPlugin({bool? isUseGoogleFCM}) {
    _instance ??= TimUiKitPushPlugin._internal(isUseGoogleFCM: isUseGoogleFCM);
    return _instance!;
  }

  static const MethodChannel _channel = MethodChannel('tim_ui_kit_push_plugin');

  /// If Google FCM needed, require Google Service on device, depends on your main customers and users
  late final bool isUseGoogleFCM;

  /// [Developers should not use this field directly] Flutter push implement
  late FlutterPushBase flutterPush;

  /// [Developers should not use this field directly] Bind the click callback
  PushClickAction? onClickNotification;

  /// [Developers should not use this field directly] Determine whether to execute the push logic in the Dart layer
  bool isUseFlutterPlugin = false;

  /// [Developers should not use this field directly] Constructor, initialize the plug-in
  _initPlugin(isUseGoogleFCMBool) {
    _channel.setMethodCallHandler(_handleMethod);
    isUseGoogleFCM = isUseGoogleFCMBool;
    if (isUseGoogleFCM && Platform.isAndroid) {
      flutterPush = GoogleFCMImpl();
      if (flutterPush.isSupport()) {
        print("TUIKitPush | Dart Plugin | USE_GOOGLE_FCM");
        isUseFlutterPlugin = true;
      }
    }
    if (Platform.isIOS) {
      print("TUIKitPush | Dart Plugin | USE_iOS");
      isUseFlutterPlugin = true;
      flutterPush = AppleAPNSImpl();
    }
  }

  /// get version
  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    switch (call.method) {
      case "TIMPushClickAction":
        print(
            "TUIKitPush | Dart Plugin | on_handleMethod | TIMPushClickAction");
        return onClickNotification!(call.arguments.cast<String, dynamic>());
      default:
        throw UnsupportedError("Unrecongnized Event");
    }
  }

  /// Initialize the push capobility for each channel
  void init(
      {required PushClickAction pushClickAction, PushAppInfo? appInfo}) async {
    if (Platform.isAndroid && await _channel.invokeMethod("isEmuiRom")) {
      // 因华为需要使用native异步校验，放到这边进行
      print("TUIKitPush | Dart Plugin | USE HUAWEI");
      isUseFlutterPlugin = true;
      flutterPush = HuaweiImpl();
    }

    print("TUIKitPush | DART | INIT, isUseFlutterPlugin: $isUseFlutterPlugin");
    onClickNotification = pushClickAction;

    if (isUseFlutterPlugin) {
      flutterPush.init(pushClickAction);
      return;
    }

    if (Platform.isAndroid && appInfo != null) {
      await Utils.setAppInfoForChannel(_channel, appInfo);
    }

    _channel.invokeMethod("initPush");
  }

  /// Require the notification permission
  Future<void> requireNotificationPermission() async {
    if (isUseFlutterPlugin) {
      flutterPush.requirePermission();
    }
    await _channel.invokeMethod("getNotificationPermission");
    return;
  }

  /// Set badge number, only works with XIAOMI(MIUI6 - MIUI 11), HUAWEI, HONOR, vivo and OPPO devices
  void setBadgeNum(int badgeNum) async {
    if (Platform.isAndroid) {
      _channel.invokeMethod("setBadgeNum", {
        "badgeNum": "$badgeNum",
      });
    }
  }

  /// Clear all the notification for current application
  void clearAllNotification() async {
    _channel.invokeMethod("clearAllNotification");
  }

  /// Get the Device Push token
  Future<String> getDevicePushToken() async {
    String token = "";
    try {
      if (isUseFlutterPlugin) {
        print("TUIKitPush | Dart | getTokenByFlutter");
        token = await flutterPush.getToken() ?? flutterPush.token;
        print("TUIKitPush | Dart | getTokenByFlutter | DeviceToken: $token");
      } else {
        print("TUIKitPush | Dart | getTokenByNative");
        token = await _channel.invokeMethod("getPushToken");
        print("TUIKitPush | Dart | getTokenByNative | DeviceToken: $token");
      }
    } catch (err) {
      print("getDevicePushToken err $err");
    }
    return token;
  }

  /// Get the brand of the manufacturer in lowercase letter format, only works for Android device
  static Future<String?> getOtherPushType() async {
    return await _channel.invokeMethod("getDeviceManufacturer");
  }

  /// Find the buz_id for current device from `PushAppInfo`
  static Future<int?> getBuzId(PushAppInfo appInfo) async {
    if (Platform.isIOS) {
      return appInfo.apple_buz_id;
    }
    String device = await getOtherPushType() ?? "";
    print("TUIKitPush | Dart | getOtherPushType | device: $device");
    switch (device) {
      case 'oppo':
      case 'oneplus':
      case 'realme':
        if (appInfo.oppo_buz_id != null) {
          return appInfo.oppo_buz_id;
        }
        break;
      case 'xiaomi':
      case 'mi':
      case 'blackshark':
        if (appInfo.mi_buz_id != null) {
          return appInfo.mi_buz_id;
        }
        break;
      case 'huawei':
      case 'honor':
        if (appInfo.hw_buz_id != null) {
          return appInfo.hw_buz_id;
        }
        break;
      case 'meizu':
        if (appInfo.mz_buz_id != null) {
          return appInfo.mz_buz_id;
        }
        break;
      case 'vivo':
      case 'iqoo':
        if (appInfo.vivo_buz_id != null) {
          return appInfo.vivo_buz_id;
        }
        break;
      default:
        if (appInfo.google_buz_id != null) {
          return appInfo.google_buz_id;
        }
        break;
    }

    if (await _channel.invokeMethod("isOppoRom") &&
        appInfo.oppo_buz_id != null) {
      return appInfo.oppo_buz_id;
    }
    if (await _channel.invokeMethod("isMiuiRom") && appInfo.mi_buz_id != null) {
      return appInfo.mi_buz_id;
    }
    if (await _channel.invokeMethod("isEmuiRom") && appInfo.hw_buz_id != null) {
      return appInfo.hw_buz_id;
    }
    if (await _channel.invokeMethod("isMeizuRom") &&
        appInfo.mz_buz_id != null) {
      return appInfo.mz_buz_id;
    }
    if (await _channel.invokeMethod("isVivoRom") &&
        appInfo.vivo_buz_id != null) {
      return appInfo.vivo_buz_id;
    }
    if (appInfo.google_buz_id != null) {
      return appInfo.google_buz_id;
    }

    return 0;
  }

  /// Create notification channel, only works for Android device
  void createNotificationChannel(
      {required String channelId,
      required String channelName,
      required String channelDescription}) async {
    if (Platform.isAndroid) {
      _channel.invokeMethod("createNotificationChannel", {
        "channelId": channelId,
        "channelName": channelName,
        "channelDescription": channelDescription
      });
    }
  }
}
